==> silizium-binerdy-0.0.3.tar.gz: silizium-binerdy-0.0.3/README.md <==
| Travis CI                                   | Coveralls                                            |
|---------------------------------------------|------------------------------------------------------|
| [![Build Status][travis-badge]][travis-url] | [![Coverage status][coveralls-badge]][coveralls-url] |

| Travis build history                                  |
|-------------------------------------------------------|
| [![Travis build history][travis-history]][travis-url] |

# swt-19fs-silizium
Source code for the wiki philosopy game in the module swt fs19

## geckodriver
You need to download and add geckodriver to your path environment. You can get it here: https://github.com/mozilla/geckodriver/releases

## install
Code is released under https://pypi.org/project/silizium-binerdy/
```
pip install silizium-binerdy
```

## cli usage
For windows user copy your python.exe and rename the copy to python3.exe in your python installation folder. Then you should be able to execute following command.
```
silizium-cli.py -w "Hund" -l 20
```

[travis-url]: https://travis-ci.org/binerdy/swt-19fs-silizium
[travis-badge]: https://travis-ci.org/binerdy/swt-19fs-silizium.svg?branch=master
[travis-history]: https://buildstats.info/travisci/chart/binerdy/swt-19fs-silizium?branch=master&includeBuildsFromPullRequest=false

[coveralls-badge]: https://coveralls.io/repos/github/binerdy/swt-19fs-silizium/badge.svg?branch=master
[coveralls-url]: https://coveralls.io/github/binerdy/swt-19fs-silizium?branch=master

==> silizium-binerdy-1.0.1.tar.gz: silizium-binerdy-1.0.1/README.md <==
| Travis CI                                   | Coveralls                                            |
|---------------------------------------------|------------------------------------------------------|
| [![Build Status][travis-badge]][travis-url] | [![Coverage status][coveralls-badge]][coveralls-url] |

| Travis build history                                  |
|-------------------------------------------------------|
| [![Travis build history][travis-history]][travis-url] |

# swt-19fs-silizium
Source code for the wiki philosopy game in the module swt fs19

## geckodriver
You need to download and add geckodriver to your path environment. You can get it here: https://github.com/mozilla/geckodriver/releases

## install
Code is released under https://pypi.org/project/silizium-binerdy/
```
pip install silizium-binerdy
```

## cli usage
Windows users: Use MINGW64 (git bash) console and copy your python.exe and rename the copy to python3.exe in your python installation folder. Then you should be able to execute following command.
```
silizium-cli.py -w "Hund" -l 20
```

[travis-url]: https://travis-ci.org/binerdy/swt-19fs-silizium
[travis-badge]: https://travis-ci.org/binerdy/swt-19fs-silizium.svg?branch=master
[travis-history]: https://buildstats.info/travisci/chart/binerdy/swt-19fs-silizium?branch=master&includeBuildsFromPullRequest=false

[coveralls-badge]: https://coveralls.io/repos/github/binerdy/swt-19fs-silizium/badge.svg?branch=master
[coveralls-url]: https://coveralls.io/github/binerdy/swt-19fs-silizium?branch=master
